package com.ruoyi.care.service;

import java.util.List;
import com.ruoyi.care.domain.CareRecords;

/**
 * 111Service接口
 * 
 * @author qy
 * @date 2025-01-07
 */
public interface ICareRecordsService 
{
    /**
     * 查询111
     * 
     * @param recordId 111主键
     * @return 111
     */
    public CareRecords selectCareRecordsByRecordId(Long recordId);

    /**
     * 查询111列表
     * 
     * @param careRecords 111
     * @return 111集合
     */
    public List<CareRecords> selectCareRecordsList(CareRecords careRecords);

    /**
     * 新增111
     * 
     * @param careRecords 111
     * @return 结果
     */
    public int insertCareRecords(CareRecords careRecords);

    /**
     * 修改111
     * 
     * @param careRecords 111
     * @return 结果
     */
    public int updateCareRecords(CareRecords careRecords);

    /**
     * 批量删除111
     * 
     * @param recordIds 需要删除的111主键集合
     * @return 结果
     */
    public int deleteCareRecordsByRecordIds(Long[] recordIds);

    /**
     * 删除111信息
     * 
     * @param recordId 111主键
     * @return 结果
     */
    public int deleteCareRecordsByRecordId(Long recordId);
}
